@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2021-11-29 16:38:45
+@LastEditTime: 2021-12-21 19:51:19
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
@@ -28,7 +28,8 @@ class InstantiateAppHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         user_nick = self.get_user_nick()
         access_token = self.get_param("access_token")
-        is_log = bool(self.get_param("is_log",False))
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
 
         cache_key = f"instantiate:{user_nick}"
         if SevenHelper.is_continue_request(cache_key, 10000) == True:
@@ -86,7 +87,8 @@ class VersionUpgradeHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         access_token = self.get_param("access_token")
         user_nick = self.get_user_nick()
-        is_log = bool(self.get_param("is_log", False))
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
 
         base_info = BaseInfoModel(context=self).get_entity()
         client_ver = base_info.client_ver
