@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-11-19 09:53:03
+@LastEditTime: 2021-11-29 16:39:17
 @LastEditors: HuangJianYi
-@Description: 
+@Description: 小活动模块（机台）
 """
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.handlers.frame_base import *
@@ -92,6 +92,8 @@ class SaveActModuleHandler(ClientBaseHandler):
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.response_json_success(invoke_result_data.data["new"].id)
 
 
