@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-12-01 18:11:13
+@LastEditTime: 2021-12-23 16:34:49
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -42,8 +42,21 @@ class PayOrderListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
+        condition = ""
+        params = []
+        order_by = "pay_date desc"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        else:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "pay_date desc"
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, nick_name, pay_date_start, pay_date_end, page_size, page_index))
+        page_info = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, nick_name, pay_date_start, pay_date_end, page_size=page_size, page_index=page_index, order_by=order_by, condition=condition, params=params)
+        ref_params = {}
+        page_info.data = self.business_process_executed(page_info.data, ref_params)
+        return self.response_json_success(page_info)
 
 
 class PrizeOrderListHandler(ClientBaseHandler):
@@ -81,7 +94,6 @@ class PrizeOrderListHandler(ClientBaseHandler):
         real_name = self.get_param("real_name")
         telephone = self.get_param("telephone")
         address = self.get_param("address")
-        real_name = self.get_param("real_name")
         order_status = int(self.get_param("order_status",-10))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
@@ -94,12 +106,21 @@ class PrizeOrderListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
+        condition = ""
+        params = []
+        order_by = "create_date desc"
+        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
+        else:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False)
+        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
@@ -152,6 +173,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         condition = ""
         params = []
         order_by ="create_date desc"
+        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
@@ -159,8 +181,9 @@ class PrizeRosterListHandler(ClientBaseHandler):
             condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         order_base_model = OrderBaseModel(context=self)
-        page_info = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params,is_cache=False)
+        page_info = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
@@ -212,10 +235,17 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         express_company = self.get_param("express_company")
         express_no = self.get_param("express_no")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         order_base_model = OrderBaseModel(context=self)
         invoke_result_data = order_base_model.update_prize_order_status(app_id, prize_order_id, order_status, express_company, express_no)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success ==False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -241,10 +271,17 @@ class ImportPrizeOrderHandler(ClientBaseHandler):
         content_type = int(self.get_param("content_type", 1))
         ref_head_name = self.get_param("ref_head_name", "小程序订单号")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         order_base_model = OrderBaseModel(context=self)
         invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content_type, content, ref_head_name)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success ==False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -286,13 +323,24 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         order_status = int(self.get_param("order_status", -10))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
-
-        order_by = "create_date desc"
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
+        condition = ""
+        params = []
+        order_by = "create_date desc"
+        field = "*"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success("")
+        else:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+
         order_base_model = OrderBaseModel(context=self)
-        prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=True, is_cache=False).data
+        prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params).data
         ref_params = {}
         result_data = self.business_process_executed(prize_order_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
@@ -383,8 +431,21 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
 
+        condition = ""
+        params = []
+        order_by = "create_date desc"
+        field = "*"
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success("")
+        else:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+
         order_base_model = OrderBaseModel(context=self)
-        prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end).data
+        prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False).data
         ref_params = {}
         result_data = self.business_process_executed(prize_roster_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
