@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-11-29 20:42:40
+@LastEditTime: 2021-12-23 16:20:57
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -29,7 +29,7 @@ class OrderBaseModel(FrameBaseModel):
     def __init__(self, context):
         self.context = context
         super(OrderBaseModel,self).__init__(context)
-    
+
     def _delete_prize_order_dependency_key(self,act_id):
         """
         :description: 删除订单依赖建
@@ -44,7 +44,7 @@ class OrderBaseModel(FrameBaseModel):
         except Exception as ex:
             pass
 
-    def get_prize_order_list(self,app_id,act_id,user_id,open_id,nick_name,order_no,real_name,telephone,address,order_status,create_date_start,create_date_end,page_size=20,page_index=0,order_by="create_date desc",field="*",is_search_roster=False,is_cache=True):
+    def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[]):
         """
         :description: 用户奖品订单列表
         :param app_id：应用标识
@@ -65,54 +65,59 @@ class OrderBaseModel(FrameBaseModel):
         :param field：查询字段
         :param is_search_roster：是否查询订单关联中奖记录
         :param is_cache：是否缓存
+        :param condition：条件
+        :param params：参数化数组
         :return: PageInfo
         :last_editors: HuangJianYi
         """
-        condition = "app_id=%s and act_id=%s"
-        params = [app_id,act_id]
+        where = "app_id=%s and act_id=%s"
+        params_list = [app_id,act_id]
+        if condition:
+            where += " AND " + condition
+            params_list.extend(params)
         page_info = PageInfo(page_index, page_size, 0, [])
-        
+
         if not app_id or not act_id:
             return page_info
         if user_id:
-            condition += " AND user_id=%s"
-            params.append(user_id)
+            where += " AND user_id=%s"
+            params_list.append(user_id)
         if open_id:
-            condition += " AND open_id=%s"
-            params.append(open_id)
+            where += " AND open_id=%s"
+            params_list.append(open_id)
         if order_no:
-            condition += " AND order_no=%s"
-            params.append(order_no)
+            where += " AND order_no=%s"
+            params_list.append(order_no)
         if nick_name:
-            condition += " AND user_nick=%s"
-            params.append(nick_name)
+            where += " AND user_nick=%s"
+            params_list.append(nick_name)
         if real_name:
-            condition += " AND real_name=%s"
-            params.append(real_name)
+            where += " AND real_name=%s"
+            params_list.append(real_name)
         if telephone:
-            condition += " AND telephone=%s"
-            params.append(telephone)
+            where += " AND telephone=%s"
+            params_list.append(telephone)
         if address:
             address = f"{address}%"
-            condition += " AND address like %s"
-            params.append(address)
+            where += " AND address like %s"
+            params_list.append(address)
         if order_status >=-2:
-            condition += " AND order_status=%s"
-            params.append(order_status)
+            where += " AND order_status=%s"
+            params_list.append(order_status)
         if create_date_start:
-            condition += " AND create_date>=%s"
-            params.append(create_date_start)
+            where += " AND create_date>=%s"
+            params_list.append(create_date_start)
         if create_date_end:
-            condition += " AND create_date<=%s"
-            params.append(create_date_end)
+            where += " AND create_date<=%s"
+            params_list.append(create_date_end)
         prize_order_model = PrizeOrderModel(context=self.context)
         if is_cache:
             dependency_key=f"prize_order_list:actid_{act_id}"
             if user_id:
                 dependency_key += f"_userid_{user_id}"
-            page_list, total = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, condition, "", order_by, params,dependency_key)
+            page_list, total = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, dependency_key)
         else:
-            page_list, total = prize_order_model.get_dict_page_list(field, page_index, page_size, condition, "", order_by, params)
+            page_list, total = prize_order_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         if is_search_roster == True:
             prize_roster_model = PrizeRosterModel(context=self.context)
             if page_list and len(page_list)>0:
@@ -165,7 +170,7 @@ class OrderBaseModel(FrameBaseModel):
                 params = [express_company, express_no, now_datetime, now_datetime, prize_order_id]
                 prize_order_model.update_table(update_sql, "id=%s", params)
                 prize_roster_model.update_table("logistics_status=1", "act_id=%s and order_no=%s", [prize_order.act_id,prize_order.order_no])
-            if order_status == 2:
+            elif order_status == 2:
                 update_sql = "order_status=2,modify_date=%s"
                 params = [now_datetime, prize_order_id]
                 prize_order_model.update_table(update_sql, "id=%s", params)
@@ -178,7 +183,7 @@ class OrderBaseModel(FrameBaseModel):
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message ="操作失败"
                 return invoke_result_data
-                
+
         except Exception as ex:
             self.context.logging_link_error(traceback.format_exc())
             if db_transaction.is_transaction == True:
@@ -234,7 +239,7 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法导入订单"
             return invoke_result_data
-        data = []   
+        data = []
         if content_type == 1:
             data = base64.decodebytes(content.encode())
             if not os.path.exists("temp"):
@@ -287,7 +292,7 @@ class OrderBaseModel(FrameBaseModel):
 
         return invoke_result_data
 
-    def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field='*'):
+    def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field="*",order_by="pay_date desc",condition="",params=[]):
         """
         :description: 用户购买订单列表
         :param app_id：应用标识
@@ -300,36 +305,42 @@ class OrderBaseModel(FrameBaseModel):
         :param page_size：页大小
         :param page_index：页索引
         :param field：查询字段
+        :param order_by：排序
+        :param condition：条件
+        :param params：参数化数组
         :return: PageInfo
         :last_editors: HuangJianYi
         """
-        condition = "app_id=%s and act_id=%s"
-        params = [app_id,act_id]
+        where = "app_id=%s and act_id=%s"
+        params_list = [app_id,act_id]
+        if condition:
+            where += " AND " + condition
+            params_list.extend(params)
         page_info = PageInfo(page_index, page_size, 0, [])
-        
+
         if not act_id:
             return page_info
         if not user_id and not open_id:
             return page_info
         if user_id:
-            condition += " AND user_id=%s"
-            params.append(user_id)
+            where += " AND user_id=%s"
+            params_list.append(user_id)
         if open_id:
-            condition += " AND open_id=%s"
-            params.append(open_id)
+            where += " AND open_id=%s"
+            params_list.append(open_id)
         if nick_name:
-            condition += " AND user_nick=%s"
-            params.append(nick_name)
+            where += " AND user_nick=%s"
+            params_list.append(nick_name)
         if pay_date_start:
-            condition += " AND pay_date>=%s"
-            params.append(pay_date_start)
+            where += " AND pay_date>=%s"
+            params_list.append(pay_date_start)
         if pay_date_end:
-            condition += " AND pay_date<=%s"
-            params.append(pay_date_end)
-        page_list, total = TaoPayOrderModel(context=self.context).get_dict_page_list(field, page_index, page_size, condition, "", "pay_date desc", params)
+            where += " AND pay_date<=%s"
+            params_list.append(pay_date_end)
+        page_list, total = TaoPayOrderModel(context=self.context).get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
-    
+
     def select_prize_order(self,app_id,act_id,user_id,login_token,prize_ids,real_name,telephone,province,city,county,street,address):
         """
         :description: 选择奖品进行下单
@@ -363,13 +374,13 @@ class OrderBaseModel(FrameBaseModel):
             prize_ids_list = prize_ids.split(',')
             for prize_id in prize_ids_list:
                 try:
-                    prize_id = int(prize_id)    
+                    prize_id = int(prize_id)
                 except Exception as ex:
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message ="存在无法识别的奖品标识"
                     return invoke_result_data
-                    
+
         #获取用户信息
         user_info_dict = user_info_model.get_dict("act_id=%s and user_id=%s", params=[act_id, user_id])
         if not user_info_dict:
@@ -377,7 +388,7 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "用户不存在"
             return invoke_result_data
-        if user_info_dict["login_token"] != login_token:  
+        if user_info_dict["login_token"] != login_token:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "已在另一台设备登录,无法操作"
@@ -387,7 +398,7 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "user_exception"
             invoke_result_data.error_message = "账号异常,请联系客服处理"
             return invoke_result_data
-        
+
         acquire_lock_name = f"create_prize_order_queue_{act_id}_{user_id}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
         if acquire_lock_status == False:
@@ -407,7 +418,7 @@ class OrderBaseModel(FrameBaseModel):
                 return invoke_result_data
         else:
             prize_roster_list = prize_roster_model.get_list("act_id=%s and prize_status=0")
-       
+
         prize_order_model = PrizeOrderModel(context=self.context)
         now_date = SevenHelper.get_now_datetime()
         prize_order = PrizeOrder()
@@ -474,7 +485,7 @@ class OrderBaseModel(FrameBaseModel):
             tao_pay_order_model = TaoPayOrderModel(context=self.context)
             pay_order_list = tao_pay_order_model.get_dict_list("app_id=%s and user_id=%s",field="sub_pay_order_no", params=[app_id,user_id])
             is_add = True
-            
+
         if len(pay_order_list) >0:
             for item in pay_order_list:
                 pay_order_no_list.append(item["sub_pay_order_no"])
@@ -514,7 +525,7 @@ class OrderBaseModel(FrameBaseModel):
                 act_module_dict = invoke_result_data.data["act_module_dict"]
                 user_info_dict = invoke_result_data.data["user_info_dict"]
                 identifier = invoke_result_data.data["identifier"]
-                
+
                 # 获取订单
                 app_info_dict = AppBaseModel(context=self.context).get_app_info_dict(app_id)
                 access_token = app_info_dict["access_token"] if app_info_dict else ""
@@ -528,9 +539,9 @@ class OrderBaseModel(FrameBaseModel):
                     invoke_result_data = top_base_model.get_buy_order_list(user_info_dict["open_id"], access_token,app_key,app_secret,is_log=is_log)
                     if invoke_result_data.success == True:
                         order_data = invoke_result_data.data
-                if len(order_data)>0: 
+                if len(order_data)>0:
                     pay_order_no_list,redis_init,pay_order_cache_key = self._get_pay_order_no_list(app_id,user_id)
-                    
+
                     goods_ids_list = []
                     #满足奖励条件的订单
                     reward_order_list = []
@@ -543,7 +554,7 @@ class OrderBaseModel(FrameBaseModel):
                             goods_ids_list.append(price_gear_dict["goods_id"])
                     else:
                         goods_ids_list.append(str(goods_id))
-                        
+
                     for item in order_data:
                         for order in item["orders"]["order"]:
                             if str(order["num_iid"]) in goods_ids_list:
@@ -555,7 +566,7 @@ class OrderBaseModel(FrameBaseModel):
                                     order["tid"] = item["tid"]
                                     order["pay_time"] = item["pay_time"]
                                     all_order_list.append(order)
-                                    
+
                     pay_price = 0
                     pay_num = 0
                     buy_num = 0
@@ -582,7 +593,7 @@ class OrderBaseModel(FrameBaseModel):
                                         continue
                                     if sku_id and str(sku_id) != str(order["sku_id"]):
                                         continue
-                                        
+
                                 tao_pay_order = TaoPayOrder()
                                 tao_pay_order.app_id = app_id
                                 tao_pay_order.act_id = act_id
@@ -605,22 +616,22 @@ class OrderBaseModel(FrameBaseModel):
                                 tao_pay_order.asset_type = asset_type
                                 tao_pay_order.asset_object_id = asset_object_id
                                 tao_pay_order.surplus_count = order['num']
-                                tao_pay_order.pay_date = order['pay_time'] 
+                                tao_pay_order.pay_date = order['pay_time']
                                 tao_pay_order_list.append(tao_pay_order)
-                                
+
                                 pay_price = decimal.Decimal(pay_price) + payment
                                 pay_num = pay_num + 1
-                                buy_num = buy_num + order['num']          
+                                buy_num = buy_num + order['num']
                         except Exception as ex:
                             self.context.logging_link_info(str(order) + "【同步淘宝支付订单】" + traceback.format_exc())
                             continue
                     if len(tao_pay_order_list) > 0:
                         result = TaoPayOrderModel(context=self.context).add_list(tao_pay_order_list)
-                        if result == True and buy_num > 0: 
+                        if result == True and buy_num > 0:
                             asset_base_model = AssetBaseModel(context=self.context)
                             invoke_result_data.data = {}
                             invoke_result_data.data["asset_list"] = []
-                            for item in tao_pay_order_list:       
+                            for item in tao_pay_order_list:
                                 only_id = str(item.sub_pay_order_no)
                                 asset_invoke_result_data = asset_base_model.update_user_asset(app_id,act_id,module_id,user_id,user_info_dict["open_id"],user_info_dict["user_nick"],asset_type,item.buy_num,item.asset_object_id,1,"","","购买",only_id,handler_name,request_code,info_json={})
                                 if asset_invoke_result_data.success == False:
@@ -655,17 +666,17 @@ class OrderBaseModel(FrameBaseModel):
                 else:
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "没有订单"  
+                    invoke_result_data.error_message = "没有订单"
         except Exception as ex:
             self.context.logging_link_error("【同步淘宝支付订单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = "系统繁忙,请稍后再试"    
+            invoke_result_data.error_message = "系统繁忙,请稍后再试"
         finally:
             self.business_process_executed(act_id,module_id,user_id,handler_name,acquire_lock_name,identifier)
 
         return invoke_result_data
-        
+
     def get_prize_roster_list(self,app_id,act_id,module_id,user_id,open_id="",user_nick="",order_no="",goods_type=-1,prize_type=-1,logistics_status=-1,prize_status=-1,pay_status=-1,page_size=20,page_index=0,create_date_start="",create_date_end="",order_by="create_date desc",field="*",condition="",params=[],is_cache=True):
         """
         :description: 用户中奖记录列表
@@ -700,7 +711,7 @@ class OrderBaseModel(FrameBaseModel):
             where += " AND " + condition
             params_list.extend(params)
         page_info = PageInfo(page_index, page_size, 0, [])
-        
+
         if not app_id or not act_id:
             return page_info
         if module_id:
@@ -739,12 +750,12 @@ class OrderBaseModel(FrameBaseModel):
         if create_date_end:
             where += " AND create_date<=%s"
             params_list.append(create_date_end)
-        
+
         prize_roster_model = PrizeRosterModel(context=self.context)
         if is_cache:
             dependency_key = f"prize_roster_list:actid_{act_id}"
             if user_id:
-                    dependency_key += f"_userid_{user_id}"
+                dependency_key += f"_userid_{user_id}"
             page_list, total = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list,dependency_key)
         else:
             page_list, total = prize_roster_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
@@ -827,6 +838,5 @@ class OrderBaseModel(FrameBaseModel):
                     act_module_filter = [act_module for act_module in act_module_list if false_act_prize.module_id == act_module.id]
                     prize_roster["module_name"] = act_module_filter[0].module_name if len(act_module_filter) > 0 else ""
                     prize_roster_list.append(prize_roster)
-        
+
         return prize_roster_list
-        
\ No newline at end of file
