@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-12-10 14:48:21
+@LastEditTime: 2021-12-16 09:18:13
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -100,7 +100,7 @@ class PrizeBaseModel():
             page_list, total = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)    
         return page_list, total
 
-    def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,surplus,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
+    def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,prize_total,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
         """
         :description: 保存活动模块信息
         :param app_id: 应用标识
@@ -121,7 +121,7 @@ class PrizeBaseModel():
         :param chance: 概率
         :param prize_limit: 中奖限制数
         :param is_prize_notice: 是否显示跑马灯(1是0否)
-        :param surplus: 当前库存
+        :param prize_total: 变动后的奖品总数
         :param is_surplus: 是否显示奖品库存（1显示0-不显示）
         :param lottery_type: 出奖类型（1概率出奖 2强制概率）
         :param tag_name: 标签名称(奖项名称)
@@ -211,16 +211,16 @@ class PrizeBaseModel():
         act_prize.modify_date = now_datetime
         
         # 奖品类型为参与奖时
-        surplus = 9999 if prize_type == 4 else surplus
+        prize_total = 9999 if prize_type == 4 else prize_total
         
         if is_add:
             act_prize.create_date = now_datetime
-            act_prize.surplus = surplus
-            act_prize.prize_total = surplus
+            act_prize.surplus = prize_total
+            act_prize.prize_total = prize_total
             act_prize.id = act_prize_model.add_entity(act_prize)
         else:
             act_prize_model.update_entity(act_prize,exclude_field_list="app_id,act_id,module_id,prize_total,surplus,hand_out")
-            operate_num = surplus - act_prize.prize_total
+            operate_num = prize_total - act_prize.prize_total
             if operate_num != 0:
                 act_prize_model.update_table(f"surplus=surplus+{operate_num},prize_total=prize_total+{operate_num}", "id=%s", act_prize.id)
             
